@@ -81,30 +81,27 @@ def process(smpp_client, queue):
                         )
                     sender_id = document['json'].get('sender_id', 'bip')
                     request_id = document['headers']['X-Request-Id']
-                    log_msg = (
-                        "POST smsc: tentative d'envoi de sms vers {}"
-                        ).format(msisdn)
-                    journal.send(
-                        log_msg,
-                        REQUEST_ID=request_id
-                        )
-                    try:
-                        # international
-                        if document['json'].get("intl"):
-                            smpp_client.send_sms(
-                                msisdn,
-                                message,
-                                intl=True,
-                                request_id=request_id,
-                                sender_id=sender_id
-                                )
-                        else:
-                            if (
-                                (msisdn[-9:]).startswith("34")
-                                or (msisdn[-9:]).startswith("39")
-                            ):
-                                LOGS.logger.error(
-                                    "Erreur envoie sms {}".format(msisdn)
+                    if (msisdn[-9:]).startswith("34") or (msisdn[-9:]).startswith("39"):
+                        LOGS.logger.error(
+                            "Erreur envoie sms {}".format(msisdn)
+                            )
+                    else:
+                        log_msg = (
+                            "POST smsc: tentative d'envoi de sms vers {}"
+                            ).format(msisdn)
+                        journal.send(
+                            log_msg,
+                            REQUEST_ID=request_id
+                            )
+                        try:
+                            # international
+                            if document['json'].get("intl"):
+                                smpp_client.send_sms(
+                                    msisdn,
+                                    message,
+                                    intl=True,
+                                    request_id=request_id,
+                                    sender_id=sender_id
                                     )
                             else:
                                 smpp_client.send_sms(
@@ -113,55 +110,55 @@ def process(smpp_client, queue):
                                     request_id=request_id,
                                     sender_id=sender_id
                                     )
-                    except Exception as exc:
-                        log_msg = (
-                            "Erreur survenue lors de l'envoi: {}"
-                            ).format(exc)
-                        journal.send(
-                            log_msg,
-                            REQUEST_ID=request_id
-                            )
-                        ch.basic_ack(delivery_tag=method.delivery_tag)
-                        response['status'] = 500
-                        response['code'] = SERVICE_CODE + '-5000'
-                        response['error'] = 'Erreur interne'
-                        response['message'] = {
-                            'msisdn': msisdn,
-                            'date': datetime.datetime.now().strftime(
-                                '%d-%m-%Y %H:%M:%S'
-                                ),
-                            'error': exc
-                            }
-                    else:
-                        log_msg = (
-                            "POST smsc: delivre au smsc "
-                            "pour envoi vers {}"
-                            ).format(msisdn)
-                        journal.send(
-                            log_msg,
-                            REQUEST_ID=request_id
-                            )
-                        ch.basic_ack(delivery_tag=method.delivery_tag)
-                        response['message'] = smpp_client.infos
-                        if smpp_client.infos['submit']:
-                            response['code'] = SERVICE_CODE+'-200'
+                        except Exception as exc:
+                            log_msg = (
+                                "Erreur survenue lors de l'envoi: {}"
+                                ).format(exc)
+                            journal.send(
+                                log_msg,
+                                REQUEST_ID=request_id
+                                )
+                            ch.basic_ack(delivery_tag=method.delivery_tag)
+                            response['status'] = 500
+                            response['code'] = SERVICE_CODE + '-5000'
+                            response['error'] = 'Erreur interne'
+                            response['message'] = {
+                                'msisdn': msisdn,
+                                'date': datetime.datetime.now().strftime(
+                                    '%d-%m-%Y %H:%M:%S'
+                                    ),
+                                'error': exc
+                                }
                         else:
-                            if smpp_client.infos['submit'] is None:
-                                response['code'] = SERVICE_CODE+'-5004'
-                                response['status'] = 504
+                            log_msg = (
+                                "POST smsc: delivre au smsc "
+                                "pour envoi vers {}"
+                                ).format(msisdn)
+                            journal.send(
+                                log_msg,
+                                REQUEST_ID=request_id
+                                )
+                            ch.basic_ack(delivery_tag=method.delivery_tag)
+                            response['message'] = smpp_client.infos
+                            if smpp_client.infos['submit']:
+                                response['code'] = SERVICE_CODE+'-200'
                             else:
-                                response['code'] = SERVICE_CODE+'-5003'
-                                response['status'] = 503
-                    infos = {i: j for i, j in response.items()}
-                    infos['service'] = 'smsc'
-                    infos['request_id'] = request_id
-                    if 'index' in document:
-                        infos['index'] = document['index']
-                    requests.post(
-                        'https://{fqdn}/requests'.format(fqdn=APIGW),
-                        json=infos
-                        )
-                    time.sleep(0.75)
+                                if smpp_client.infos['submit'] is None:
+                                    response['code'] = SERVICE_CODE+'-5004'
+                                    response['status'] = 504
+                                else:
+                                    response['code'] = SERVICE_CODE+'-5003'
+                                    response['status'] = 503
+                        infos = {i: j for i, j in response.items()}
+                        infos['service'] = 'smsc'
+                        infos['request_id'] = request_id
+                        if 'index' in document:
+                            infos['index'] = document['index']
+                        requests.post(
+                            'https://{fqdn}/requests'.format(fqdn=APIGW),
+                            json=infos
+                            )
+                        time.sleep(0.75)
     connection = pika.BlockingConnection(
         pika.ConnectionParameters(
             host='localhost',
